# Changelog

## [1.0.3] - 2021-03-25

## Feature

- Add asUrl parameter in the attachments info. This used to get the full path of an attachment (For example
  with hash storage).

## [1.0.2] - 2021-03-09

### Fixed

- Fixed wrong type definition for python2

## [1.0.1] - 2021-03-08

First release.
